@@ -90,10 +90,16 @@ class UiCursesBase:
         b"KEY_UP": View.key_up,
         b"KEY_PPAGE": View.key_pgup,
         b"KEY_NPAGE": View.key_pgdown,
+        b"KEY_HOME": View.key_home,
+        b"KEY_END": View.key_end,
         b"KEY_BACKSPACE": View.key_backspace,
         b"KEY_DC": View.key_delete,
         b"KEY_LEFT": View.key_left,
         b"KEY_RIGHT": View.key_right,
+        b"^A": View.key_bol,
+        b"^E": View.key_eol,
+        b"^U": View.key_killbol,
+        b"^K": View.key_killeol,
     }
 
     def __init__(self):
